**************************
sunkit-image Documentation
**************************

Welcome to the sunkit-image documentation. sunkit-image is a community-developed,
free and open-source solar data image analysis environment for Python.

We have a documentation :any:`index <genindex>` and a :any:`module <modindex>` list.

.. toctree::
  :maxdepth: 2

  code_ref/index
  generated/gallery/index
  whatsnew/index
  format
